@@ -20,19 +20,32 @@ if pants_jupyter_plugin.__version__ in previous_tag:
     )
 
 changes = subprocess.check_output(
-    args=["git", "log", "--oneline", "--no-decorate", f"HEAD...{previous_tag}"],
+    args=[
+        "git",
+        "log",
+        "--pretty=format:+ [%h](https://github.com/pantsbuild/pants-jupyter-plugin/commit/%h) %s",
+        f"HEAD...{previous_tag}",
+    ],
 ).decode()
 
-with open("CHANGES.md", "a") as fp:
+with open("CHANGES.md") as fp:
+    # Discard title and blank line following it.
+    fp.readline()
+    fp.readline()
+
+    changelog = fp.read()
+
+with open("CHANGES.md", "w") as fp:
     fp.write(
         dedent(
             """\
+            # Release Notes
+
             ## {version}
 
             {changes}
+
+            {changelog}
             """
-        ).format(
-            version=pants_jupyter_plugin.__version__,
-            changes=os.linesep.join(f"+ {line}" for line in changes.splitlines()),
-        )
+        ).format(version=pants_jupyter_plugin.__version__, changes=changes, changelog=changelog)
     )
